@@ -47,9 +47,8 @@ class ReplicaClient(BaseClient):
         """
         List file replicas for a list of data identifiers (DIDs).
 
-
-
-        :param dids: The list of data identifiers (DIDs).
+        :param dids: The list of data identifiers (DIDs) like :
+        [{'scope': <scope1>, 'name': <name1>}, {'scope': <scope2>, 'name': <name2>}, ...]
         :param schemes: A list of schemes to filter the replicas. (e.g. file, http, ...)
         :param unavailable: Also include unavailable replicas in the list.
         :param metalink: ``None`` (default) retrieves as JSON,
@@ -73,30 +72,42 @@ class ReplicaClient(BaseClient):
         # pass json dict in querystring
         r = self._send_request(url, headers=headers, type='POST', data=dumps(data))
         if r.status_code == codes.ok:
-            if metalink is None:
+            if not metalink:
                 return self._load_json_data(r)
-            else:
-                return r.text
+            return r.text
         exc_cls, exc_msg = self._get_exception(r.headers)
         raise exc_cls(exc_msg)
 
-    def add_replica(self, rse, scope, name, bytes, adler32, md5=None, meta={}):
+    def add_replica(self, rse, scope, name, bytes, adler32, pfn=None, md5=None, meta={}):
         """
         Add file replicas to a RSE.
 
         :param rse: the RSE name.
-        :param files: The list of files.
+        :param scope: The scope of the file.
+        :param name: The name of the file.
+        :param bytes: The size in bytes.
+        :param adler32: adler32 checksum.
+        :param pfn: PFN of the file for non deterministic RSE.
+        :param md5: md5 checksum.
+        :param meta: Metadata attributes.
 
         :return: True if files were created successfully.
+
         """
-        return self.add_replicas(rse=rse, files=[{'scope': scope, 'name': name, 'bytes': bytes, 'meta': meta, 'adler32': adler32, 'md5': md5}])
+        dict = {'scope': scope, 'name': name, 'bytes': bytes, 'meta': meta, 'adler32': adler32}
+        if md5:
+            dict['md5'] = md5
+        if pfn:
+            dict['pfn'] = pfn
+        return self.add_replicas(rse=rse, files=[dict])
 
     def add_replicas(self, rse, files):
         """
         Bulk add file replicas to a RSE.
 
         :param rse: the RSE name.
-        :param files: The list of files.
+        :param files: The list of files. This is a list of DIDs like :
+        [{'scope': <scope1>, 'name': <name1>}, {'scope': <scope2>, 'name': <name2>}, ...]
 
         :return: True if files were created successfully.
         """
@@ -113,7 +124,8 @@ class ReplicaClient(BaseClient):
         Bulk delete file replicas from a RSE.
 
         :param rse: the RSE name.
-        :param files: The list of files.
+        :param files: The list of files. This is a list of DIDs like :
+        [{'scope': <scope1>, 'name': <name1>}, {'scope': <scope2>, 'name': <name2>}, ...]
 
         :return: True if files have been deleted successfully.
         """
